<?php

namespace Laravelista\Algo\Controllers;

use Illuminate\Http\Request;
use Laravelista\Algo\Helpers\ValidateLocale;
use Laravelista\Algo\Models\Post;
use Laravelista\Algo\Helpers\Slug;
use Illuminate\Validation\Rule;

class PostTranslationController extends Controller
{
    protected $validateLocale;

    public function __construct(ValidateLocale $validateLocale)
    {
        $this->validateLocale = $validateLocale;
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Post $post
     * @param string $locale
     * @return \Illuminate\Http\Response
     */
    public function edit(Post $post, $locale)
    {
        $this->validateLocale->validate($locale);

        return view('algo::posts.translations')
            ->withPost($post)
            ->withLocale($locale);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param Post $post
     * @param string $locale
     * @param Slug $slug
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Post $post, $locale, Slug $slug)
    {
        $this->validateLocale->validate($locale);

        $validatedData = $request->validate([
            'title' => ['required', 'string', 'max:255'],
            'intro' => ['nullable', 'string', 'max:255'],
            'content' => ['required', 'string'],
            'slug' => [
                'nullable', 'string', 'max:255',
                Rule::unique('post_translations')
                    ->ignore($post->id, 'post_id')
                    ->where('locale', $locale)
            ],
        ]);

        $post->translateOrNew($locale)->title = $validatedData['title'];
        $post->translateOrNew($locale)->intro = $validatedData['intro'];
        $post->translateOrNew($locale)->content = $validatedData['content'];
        $post->translateOrNew($locale)->slug = $slug->get($validatedData['slug'], $validatedData['title']);
        $post->save();

        return redirect()
            ->route('algo.posts.translations.edit', [
                $post->id, $locale
            ])
            ->with('status', 'Objava prevedena!');
    }
}
