<?php

namespace Laravelista\Algo\Controllers;

use Illuminate\Http\Request;
use Illuminate\Validation\Rule;
use Laravelista\Algo\Models\Tag;
use Laravelista\Algo\Helpers\ValidateLocale;
use Laravelista\Algo\Helpers\Slug;

class TagTranslationController extends Controller
{
    protected $validateLocale;

    public function __construct(ValidateLocale $validateLocale)
    {
        $this->validateLocale = $validateLocale;
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Tag $tag, $locale)
    {
        $this->validateLocale->validate($locale);

        return view('algo::tags.translations')
            ->withTag($tag)
            ->withLocale($locale);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Tag $tag, $locale, Slug $slug)
    {
        $this->validateLocale->validate($locale);

        $validatedData = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'slug' => [
                'nullable', 'string', 'max:255',
                Rule::unique('tag_translations')
                    ->ignore($tag->id, 'tag_id')
                    ->where('locale', $locale)
            ],
            'description' => ['nullable', 'string'],
        ]);

        $tag->translateOrNew($locale)->name = $validatedData['name'];
        $tag->translateOrNew($locale)->slug = $slug->get($validatedData['slug'], $validatedData['name']);
        $tag->translateOrNew($locale)->description = $validatedData['description'];
        $tag->save();

        return redirect()
            ->route('algo.tags.translations.edit', [
                $tag->id, $locale
            ])
            ->with('status', 'Oznaka prevedena!');
    }
}
